-- Simple script to demonstrate how to create a camera shake effect for a
-- random amount of time
--
-- Does the following:
--
-- 1) Waits 10 seconds
-- 2) Sets the length of the cmera shake in game data to a random value between 1 & 3 secs
-- 3) Sets the size of the cmera shake in game data to a random value between 1.0 & 3.0
-- 4) Starts the camera shake with a Start Camera Shake message
-- 5) Waits a random length of time between 4 & 6 secs
-- 6) repeat from step 2

-----------------------------------------------
function Initialise()

	SendMessage("GameLogic.PlaceObjects")
	SendMessage("GameLogic.ChangeWind") 

	SetupWormsAndTeams()
	SetupInventories()
   
	TimerID = StartTimer("Shake", 10000)
	
	StartFirstTurn()	
end

-----------------------------------------------
function Shake()	

	SendMessage("RandomNumber.Get")
	Length = 1000 + math.mod(GetData("RandomNumber.Uint"), 2000)
	
	SendMessage("RandomNumber.Get")
	Magnitude = 1.0 + (GetData("RandomNumber.Float") * 2.0)
	
	SetData("Camera.Shake.Length",Length)
	SetData("Camera.Shake.Magnitude",Magnitude)
	SendMessage("Camera.ShakeStart")

	SendMessage("RandomNumber.Get")
	Length = 4000 + math.mod(GetData("RandomNumber.Float"), 2000)

	TimerID = StartTimer("Shake", Length)
	
end

-----------------------------------------------
function SetupWormsAndTeams()

   -- Activate Team 0
   lock, team = EditContainer("Team.Data00") 
   team.Active = true
   team.Name = "Good Guys"
   team.TeamColour = 0
   CloseContainer(lock) -- must close the container ASAP

   -- Activate Team 0
   lock, team = EditContainer("Team.Data01") 
   team.Active = true
   team.Name = "Bad Guys"
   team.TeamColour = 1
   CloseContainer(lock)

   -- Worm 0, Team 0
   lock, worm = EditContainer("Worm.Data00") 
   worm.Active = true
   worm.Name = "Jegg"
   worm.Energy = 100
   worm.WeaponFuse = 3
   worm.WeaponIsBounceMax = false
   worm.TeamIndex = 0
   CloseContainer(lock) 

   -- Worm 1, Team 0
   CopyContainer("Worm.Data00", "Worm.Data01")
   lock, worm = EditContainer("Worm.Data01") 
   worm.Name = "Chesh"
   CloseContainer(lock)

   -- Worm 2, Team 0
   CopyContainer("Worm.Data00", "Worm.Data02")
   lock, worm = EditContainer("Worm.Data02") 
   worm.Name = "Bruce"
   CloseContainer(lock)

   -- Worm 3, Team 0
   CopyContainer("Worm.Data00", "Worm.Data03")
   lock, worm = EditContainer("Worm.Data03") 
   worm.Name = "Kel"
   CloseContainer(lock)

   -- Worm 4, Team 1
   CopyContainer("Worm.Data00", "Worm.Data04")
   lock, worm = EditContainer("Worm.Data04") 
   worm.Name = "FuxDeluxe"
   worm.TeamIndex = 1
   CloseContainer(lock)

   -- Worm 5, Team 1
   CopyContainer("Worm.Data04", "Worm.Data05")
   lock, worm = EditContainer("Worm.Data05") 
   worm.Name = "Spadge"
   CloseContainer(lock)

   -- Worm 6, Team 1
   CopyContainer("Worm.Data04", "Worm.Data06")
   lock, worm = EditContainer("Worm.Data06") 
   worm.Name = "Dennis"
   CloseContainer(lock)

   -- Worm 7, Team 1
   CopyContainer("Worm.Data04", "Worm.Data07")
   lock, worm = EditContainer("Worm.Data07") 
   worm.Name = "Oldham"
   CloseContainer(lock)

   SendMessage("WormManager.Reinitialise")

end

-----------------------------------------------
function SetupInventories()
   -- sets up a default container and adds our selection to it
   lock, inventory = EditContainer("Inventory.Team.Default") 
   inventory.Bazooka = -1
   inventory.Sheep = -1
   inventory.Airstrike = -1
   inventory.FirePunch = -1
   inventory.Shotgun = -1
   inventory.Uzi = -1
   inventory.Minigun = -1
   inventory.SkipGo = -1
   inventory.NinjaRope = -1
   --inventory.Lasergun = -1
   inventory.Earthquake = -1
   CloseContainer(lock) -- must close the container ASAP

   -- Copies this selection into each worm
   CopyContainer("Inventory.Team.Default", "Inventory.Team00")
   CopyContainer("Inventory.Team.Default", "Inventory.Team01")

   -- Sets up some delays
   lock, delays = EditContainer("Inventory.WeaponDelays") 
   delays.Airstrike = 1
   CloseContainer(lock)
end
